@@ -79,7 +79,7 @@ def wb_to_csvfile(wb, csv_filename, dialect):
             writer.writerow([cell.value for cell in row])
 
 
-def group_wb(wb):
+def group_wb(wb, no_range=False):
     """Group lines that have the same column values in a openpyxl workbook.
     Headers are expected on the first row and references are expected in the
     first column."""
@@ -107,7 +107,14 @@ def group_wb(wb):
 
     grouped_rows = []
     for i, ref in enumerate(references):
-        grouped_rows.append((collapse(ref),) + unique_rows[i])
+        # If no_range flag, do the collapse to ensure sorting, then explode, then join to string
+        if no_range:
+            collapsed_refs = collapse(ref)
+            exploded_refs = explode(collapsed_refs)
+            joined_refs = (', ').join(exploded_refs)
+            grouped_rows.append((joined_refs,) + unique_rows[i])
+        else:
+            grouped_rows.append((collapse(ref),) + unique_rows[i])
 
     grouped_wb = pyxl.Workbook()
     grouped_ws = grouped_wb.active
@@ -872,7 +879,7 @@ def insert_part_fields_into_wb(part_fields_dict, wb, recurse=False):
 
 
 def insert_part_fields_into_xlsx(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into an XLSX spreadsheet."""
 
@@ -892,13 +899,13 @@ def insert_part_fields_into_xlsx(
     wb = insert_part_fields_into_wb(part_fields_dict, wb)
 
     if group_components:
-        wb = group_wb(wb)
+        wb = group_wb(wb, no_range)
 
     wb.save(filename)
 
 
 def insert_part_fields_into_csv(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into a CSV spreadsheet."""
 
@@ -922,13 +929,13 @@ def insert_part_fields_into_csv(
     wb = insert_part_fields_into_wb(part_fields_dict, wb)
 
     if group_components:
-        wb = group_wb(wb)
+        wb = group_wb(wb, no_range)
 
     wb_to_csvfile(wb, filename, dialect)
 
 
 def insert_part_fields_into_sch(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into a schematic."""
 
@@ -1103,13 +1110,13 @@ def insert_part_fields_into_sch(
                     # Prepend path for sheets which are nested more than once
                     sheet_file = prepend_dir + unquote(field["value"])
                     insert_part_fields_into_sch(
-                        part_fields_dict, sheet_file, recurse, group_components, backup
+                        part_fields_dict, sheet_file, recurse, group_components, backup, no_range
                     )
                     break
 
 
 def insert_part_fields_into_sch_V6(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into a schematic."""
 
@@ -1222,7 +1229,7 @@ def insert_part_fields_into_sch_V6(
 
 
 def insert_part_fields_into_lib(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into a library."""
 
@@ -1323,7 +1330,7 @@ def insert_part_fields_into_lib(
 
 
 def insert_part_fields_into_lib_V6(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into a KiCad V6 library."""
 
@@ -1428,7 +1435,7 @@ def insert_part_fields_into_lib_V6(
 
 
 def insert_part_fields_into_dcm(
-    part_fields_dict, filename, recurse, group_components, backup
+    part_fields_dict, filename, recurse, group_components, backup, no_range
 ):
     """Insert the fields in the extracted part dictionary into a DCM file."""
 
@@ -1461,7 +1468,7 @@ def insert_part_fields_into_dcm(
     dcm.save(filename)
 
 
-def insert_part_fields(part_fields_dict, filenames, recurse, group_components, backup):
+def insert_part_fields(part_fields_dict, filenames, recurse, group_components, backup, no_range):
     """Insert part fields from a dictionary into a spreadsheet, part library, or schematic."""
 
     # No files backed-up yet, so clear list of file names.
@@ -1507,7 +1514,7 @@ def insert_part_fields(part_fields_dict, filenames, recurse, group_components, b
         else:
             try:
                 insertion_function(
-                    part_fields_dict, f, recurse, group_components, backup
+                    part_fields_dict, f, recurse, group_components, backup, no_range
                 )
 
             except IOError:
@@ -1530,6 +1537,7 @@ def kifield(
     recurse=False,
     group_components=False,
     backup=True,
+    no_range=False
 ):
     """Extract fields from a set of files and insert them into another set of files."""
 
@@ -1542,5 +1550,5 @@ def kifield(
 
     # Insert entries from the dictionary into these files.
     insert_part_fields(
-        part_fields_dict, insert_filenames, recurse, group_components, backup
+        part_fields_dict, insert_filenames, recurse, group_components, backup, no_range
     )
